class LargeNumber:
    def __init__(self,value,cr=1):
        self.value=value
        self.cr = cr
        int(self.value)
        self.value = str(self.value)


def add_large(a, b):
    a = a.value
    b = b.value
    ta = list(a)
    tb = list(b)
    ta = [int(i) for i in ta]
    tb = [int(i) for i in tb]
    ta = list(reversed(ta))
    tb = list(reversed(tb))
    mlen = max(len(ta), len(tb))
    ta += [0]*(mlen-len(ta))
    tb += [0]*(mlen-len(tb))
    y = [0]*(mlen+1)
    for i in range(0, mlen):
        y[i] += ta[i] + tb[i]
        y[i+1] = int(y[i]/10)
        y[i] %= 10
    if y[mlen] == 0:
        y.pop()
    y = list(reversed(y))
    y = [str(i) for i in y]
    y = ''.join(y)

    return LargeNumber(value=y)


def sub_large(a,b):
    a = a.value
    b = b.value
    a = [int(item) for item in a]
    b = [int(item) for item in b]
    res = ''
    for i in range(len(b)):
        flag_a = len(a)-1-i
        flag_b = len(b)-1-i
        if a[flag_a]>= b[flag_b]:
            res = str(a[flag_a]-b[flag_b])+res
        else:
            res = str(10+a[flag_a]-b[flag_b])+res
            while a[flag_a-1]==0:
                a[flag_a-1]=9
                flag_a -= 1
            a[flag_a-1] -= 1
    for j in range(len(a)-1-i-1,-1,-1):
        res = str(a[j])+res
    zero_flag=0
    for i in range(len(res)):
        if res[i]!='0':
            zero_flag=1
            break
    if zero_flag==0:
        return 0
    return LargeNumber(value=res[i:])



def add(a,b):
    return str(int(a)+int(b))
def mul(a,b):
    a = a.value
    b = b.value
    N=3
    if len(b)>len(a):
        a,b=b,a
    if(len(a)<=N):
        return str(int(a)*int(b))
    mid=len(a)//2
    a1=a[:mid]
    a2=a[mid:]
    return LargeNumber(value=add(mul(a1,b)+"0"*len(a2),mul(a2,b)))


import math

class DataTable:
	def __init__(self,head,value=[]):
		self.head = head
		self.value = value
		if type(self.head) != type([1]):
			raise TypeError("Error type,:(,please input a list like \"evext.DataTable([1,2,3])\".")

	def add_item(self,adder):
		if len(adder) != len(self.head):
			raise IndexError("Error size of two lists,:(.")
		self.value.append(adder)

	def delete_item(self,name):
		flag=-1
		for i in value:
			if i[0] == name:
				value.remove(i)
				flag=1
		return flag

	def to_list(self):
		return value

	def show_itself(self):
		for i in self.head:
			print(i,end=" ")
		print(" ")
		for i in self.value:
			for j in i:
				print(j,end=" ")
			print(" ")
class List:
	def __init__(self,value):
		self.value = value
		if type(value) != type([1]):
			raise TypeError("Error type,:(,please input a list like \"evext.List([1,2,3])\".")

	def add(self,val):
		self.value.append(val)
		return value
	def delete_by_number(self,nu):
		del self.value[nu]

	def delete_by_value(self,vl):
		self.value.remove(vl)

	def len(self):
		return len(self.value)

	def value_to_np_array(self):
		import numpy as np
		self.value=np.array(self.value)

	def sort(self):
		self.value = sorted(self.value)
		return sorted(self.value)

class Stack:
	def __init__(self,max_size="Infinity",value=[]):
		self.value=value
		self.max_size = max_size
	def push_in(self,val):
		if self.max_size == "Infinity" or len(self.value) < self.max_size:
			self.value.append(val)
		else:
			raise IndexError("Cannot use function \"push_in()\" in a full stack.:(")
	def push_back(self):
		if len(self.value) == 0:
			raise IndexError("Cannot use function \"push_back()\" in an empty stack.:(")
		del self.value[-1]
	def clear(self):
		self.value = []

class Dictionary:
	def __init__(self,value):
		self.value = value
		if type(value) != type({}):
			raise TypeError("Error type,:(,please input a dictionary like \"evext.Dictionary({1:2})\".")

	def all_key(self):
		ans=[]
		for i in self.value.keys():
			ans.append(i)
		return ans

	def all_value(self):
		ans=[]
		for i in self.value.values():
			ans.append(i)
		return ans

	def get_all(self):
		return self.value.items()

	def launch(self):
		a = list(self.value.keys())
		b = list(self.value.values())
		a.append(b)
		return a

def add(a,b):
	if type(a) != type([1]) and type(b) != type([1]):
		raise TypeError("Error type,:(,please input two lists like \"evext.add([1,2,3],[4,5,6])\".")
	if len(a) != len(b):
		raise IndexError("Error size of two lists,:(.")
	end=[]
	for i in range(0,len(a)):
		end.append(a[i]+b[i])
	return end

def sub(a,b):
	if type(a) != type([1]) and type(b) != type([1]):
		raise TypeError("Error type,:(,please input two lists like \"evext.add([1,2,3],[4,5,6])\".")
	if len(a) != len(b):
		raise IndexError("Error size of two lists,:(.")
	end=[]
	for i in range(0,len(a)):
		end.append(a[i]-b[i])
	return end

def mul(a,b):
	if type(a) != type([1]) and type(b) != type([1]):
		raise TypeError("Error type,:(,please input two lists like \"evext.add([1,2,3],[4,5,6])\".")
	if len(a) != len(b):
		raise IndexError("Error size of two lists,:(.")
	end=[]
	for i in range(0,len(a)):
		end.append(a[i]/b[i])
	return end

def div(a,b):
	if type(a) != type([1]) and type(b) != type([1]):
		raise TypeError("Error type,:(,please input two lists like \"evext.add([1,2,3],[4,5,6])\".")
	if len(a) != len(b):
		raise IndexError("Error size of two lists,:(.")
	end=[]
	for i in range(0,len(a)):
		end.append(a[i]/b[i])
	return end

def factorial(end,start=1):
	ans=1
	for i in range(start,end+1):
		ans*=i
	return ans

def array_function(func="sin",nm=10,start=0,spac=1):
	ed = []
	for i in range(start,start+nm+1):
		if func == "sin":
			ed.append(math.sin(i))
		elif func == "tan":
			ed.append(math.tan(i))
		elif func == "cos":
			ed.append(math.cos(i))
		else:
			raise NameError("No math function name like \""+func+"\" ,or we haven't add this function yet. :)")

	return ed





import setuptools

with open("README.md", "r",encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="evext",
    version="1.0.0",
    author="Apple.Pie.etc",
    author_email="",
    description="A calculate Python package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/suberstring/evext",
    packages=setuptools.find_packages(),
    install_requires=[],
    entry_points={},
    classifiers=(
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)